@@ -11,9 +11,9 @@ from textwrap import dedent
 
 import path
 import pytest
-import simplesqlite
 from click.testing import CliRunner
 from pytablereader.interface import TableLoader
+from simplesqlite import SimpleSQLite
 from sqlitebiter._enum import ExitCode
 from sqlitebiter.sqlitebiter import cmd
 from sqlitebiter.subcommand._base import SourceInfo
@@ -28,16 +28,16 @@ class Test_sqlitebiter_file(object):
         TableLoader.clear_table_count()
 
     @pytest.mark.parametrize(
-        ["option_list", "expected"],
+        ["options", "expected"],
         [
             [["-h"], ExitCode.SUCCESS],
             [["file", "-h"], ExitCode.SUCCESS],
             [["gs", "-h"], ExitCode.SUCCESS],
         ],
     )
-    def test_help(self, option_list, expected):
+    def test_help(self, options, expected):
         runner = CliRunner()
-        result = runner.invoke(cmd, option_list)
+        result = runner.invoke(cmd, options)
         assert result.exit_code == expected
 
     @pytest.mark.parametrize(
@@ -101,7 +101,7 @@ class Test_sqlitebiter_file(object):
         runner = CliRunner()
 
         with runner.isolated_filesystem():
-            file_list = [
+            files = [
                 valid_json_single_file(),
                 valid_json_multi_file_1(),
                 valid_jsonlines_file(),
@@ -116,7 +116,7 @@ class Test_sqlitebiter_file(object):
                 valid_utf16_csv_file(),
             ]
 
-            result = runner.invoke(cmd, ["-o", db_path, "file"] + file_list)
+            result = runner.invoke(cmd, ["-o", db_path, "file"] + files)
 
             assert result.exit_code == ExitCode.SUCCESS
 
@@ -152,7 +152,7 @@ class Test_sqlitebiter_file(object):
         runner = CliRunner()
 
         with runner.isolated_filesystem():
-            file_list = [
+            files = [
                 invalid_csv_file(),
                 invalid_json_single_file(),
                 invalid_excel_file_1(),
@@ -163,7 +163,7 @@ class Test_sqlitebiter_file(object):
                 not_supported_format_file(),
             ]
 
-            for file_path in file_list:
+            for file_path in files:
                 result = runner.invoke(cmd, ["-o", db_path, "file", file_path])
 
                 assert result.exit_code in (ExitCode.FAILED_CONVERT, ExitCode.NO_INPUT), file_path
@@ -184,7 +184,7 @@ class Test_sqlitebiter_file(object):
         runner = CliRunner()
 
         with runner.isolated_filesystem():
-            file_list = [
+            files = [
                 valid_json_single_file(),
                 invalid_json_single_file(),
                 valid_json_multi_file_1(),
@@ -205,11 +205,11 @@ class Test_sqlitebiter_file(object):
                 not_supported_format_file(),
             ]
 
-            result = runner.invoke(cmd, ["-o", db_path, "file"] + file_list)
+            result = runner.invoke(cmd, ["-o", db_path, "file"] + files)
             assert result.exit_code == ExitCode.SUCCESS
 
-            con = simplesqlite.SimpleSQLite(db_path, "r")
-            expected_table_list = [
+            con = SimpleSQLite(db_path, "r")
+            expected_tables = [
                 "singlejson",
                 "multij1",
                 "multij2",
@@ -226,11 +226,11 @@ class Test_sqlitebiter_file(object):
                 "valid_mdtable_markdown1",
                 SourceInfo.get_table_name(),
             ]
-            actual_table_list = con.fetch_table_name_list()
+            actual_tables = con.fetch_table_names()
 
-            print_test_result(expected=expected_table_list, actual=actual_table_list)
+            print_test_result(expected=expected_tables, actual=actual_tables)
 
-            assert set(actual_table_list) == set(expected_table_list)
+            assert set(actual_tables) == set(expected_tables)
 
             expected_data_table = {
                 "singlejson": [(1, 4.0, "a"), (2, 2.1, "bb"), (3, 120.9, "ccc")],
@@ -256,7 +256,7 @@ class Test_sqlitebiter_file(object):
                 "tsv_a": [(1, 4.0, "tsv0"), (2, 2.1, "tsv1"), (3, 120.9, "tsv2")],
                 "valid_mdtable_markdown1": [(1, 123.1, "a"), (2, 2.2, "bb"), (3, 3.3, "ccc")],
             }
-            for table in con.fetch_table_name_list():
+            for table in con.fetch_table_names():
                 if table == SourceInfo.get_table_name():
                     continue
 
@@ -284,12 +284,12 @@ class Test_sqlitebiter_file(object):
 
             assert result.exit_code == ExitCode.SUCCESS
 
-            con = simplesqlite.SimpleSQLite(db_path, "r")
+            con = SimpleSQLite(db_path, "r")
             data = con.select_as_tabledata(table_name="ssv")
             expected = (
                 "table_name=ssv, "
-                "header_list=[USER, PID, %CPU, %MEM, VSZ, RSS, TTY, STAT, START, TIME, COMMAND], "
-                "rows=5"
+                "headers=[USER, PID, %CPU, %MEM, VSZ, RSS, TTY, STAT, START, TIME, COMMAND], "
+                "cols=11, rows=5"
             )
 
             assert str(data) == expected
@@ -302,19 +302,18 @@ class Test_sqlitebiter_file(object):
                 "aa,ac",
                 dedent(
                     """\
-                .. table:: valid_csv_3_1
+                    .. table:: valid_csv_3_1
 
-                    +--------------+---------+-----------+--------+------+-----+
-                    |Attribute Name|Data Type|PRIMARY KEY|NOT NULL|UNIQUE|Index|
-                    +==============+=========+===========+========+======+=====+
-                    |aa            |REAL     |           |        |      |X    |
-                    +--------------+---------+-----------+--------+------+-----+
-                    |ab            |INTEGER  |           |        |      |     |
-                    +--------------+---------+-----------+--------+------+-----+
-                    |ac            |TEXT     |           |        |      |X    |
-                    +--------------+---------+-----------+--------+------+-----+
-
-                """
+                        +-----+-------+----+---+-------+-----+-----+
+                        |Field| Type  |Null|Key|Default|Index|Extra|
+                        +=====+=======+====+===+=======+=====+=====+
+                        |aa   |REAL   |YES |   |NULL   |  X  |     |
+                        +-----+-------+----+---+-------+-----+-----+
+                        |ab   |INTEGER|YES |   |NULL   |     |     |
+                        +-----+-------+----+---+-------+-----+-----+
+                        |ac   |TEXT   |YES |   |NULL   |  X  |     |
+                        +-----+-------+----+---+-------+-----+-----+
+                    """
                 ),
             ]
         ],
@@ -327,14 +326,12 @@ class Test_sqlitebiter_file(object):
             file_path = file_creator()
             result = runner.invoke(cmd, ["-o", db_path, "--index", index_list, "file", file_path])
             print_traceback(result)
-
             assert result.exit_code == ExitCode.SUCCESS
 
             extractor = SQLiteSchemaExtractor(db_path)
-
-            print_test_result(expected=expected, actual=extractor.dumps())
-
-            assert extractor.fetch_table_schema("valid_csv_3_1").dumps() == expected
+            output = extractor.fetch_table_schema("valid_csv_3_1").dumps()
+            print_test_result(expected=expected, actual=output)
+            assert output == expected
 
     def test_normal_dup_col_csv_file(self):
         db_path = "test_dup_col.sqlite"
@@ -355,27 +352,45 @@ class Test_sqlitebiter_file(object):
             print_test_result(expected=expected, actual=extractor.dumps(**options))
             assert len(extractor.dumps(**options)) > 100
 
+    def test_normal_symbols_attr(self):
+        db_path = "test_symbols_attr.sqlite"
+        runner = CliRunner()
+        expected = dedent("symbols_attr (A1_A, B2B, C3_C)")
+
+        with runner.isolated_filesystem():
+            result = runner.invoke(
+                cmd, ["-o", db_path, "--replace-symbol", "_", "file", symbols_attr_csv_file()]
+            )
+            print_traceback(result)
+            assert result.exit_code == ExitCode.SUCCESS
+
+            extractor = SQLiteSchemaExtractor(db_path)
+            options = {"output_format": "text", "verbosity_level": 1}
+            schema = extractor.fetch_table_schema("symbols_attr")
+            print_test_result(expected=expected, actual=schema.dumps(**options))
+            assert schema.dumps(**options) == expected
+
     def test_normal_append(self):
         db_path = "test.sqlite"
         runner = CliRunner()
 
         with runner.isolated_filesystem():
-            file_list = [valid_json_multi_file_2_1()]
+            files = [valid_json_multi_file_2_1()]
             table_name = "multij2"
-            expected_table_list = [table_name, SourceInfo.get_table_name()]
+            expected_tables = [table_name, SourceInfo.get_table_name()]
 
             # first execution without --append option (new) ---
-            result = runner.invoke(cmd, ["-o", db_path, "file"] + file_list)
+            result = runner.invoke(cmd, ["-o", db_path, "file"] + files)
             print_traceback(result)
             assert result.exit_code == ExitCode.SUCCESS
 
-            con = simplesqlite.SimpleSQLite(db_path, "r")
+            con = SimpleSQLite(db_path, "r")
 
-            actual_table_list = con.fetch_table_name_list()
+            actual_tables = con.fetch_table_names()
 
-            print_test_result(expected=expected_table_list, actual=actual_table_list)
+            print_test_result(expected=expected_tables, actual=actual_tables)
 
-            assert set(actual_table_list) == set(expected_table_list)
+            assert set(actual_tables) == set(expected_tables)
 
             actual_data = con.select("*", table_name=table_name).fetchall()
             expected_data = [(1, 4.0, "a"), (2, 2.1, "bb"), (3, 120.9, "ccc")]
@@ -385,17 +400,17 @@ class Test_sqlitebiter_file(object):
             assert expected_data == actual_data
 
             # second execution with --append option ---
-            result = runner.invoke(cmd, ["-o", db_path, "--append", "file"] + file_list)
+            result = runner.invoke(cmd, ["-o", db_path, "--append", "file"] + files)
             print_traceback(result)
             assert result.exit_code == ExitCode.SUCCESS
 
-            con = simplesqlite.SimpleSQLite(db_path, "r")
+            con = SimpleSQLite(db_path, "r")
 
-            actual_table_list = con.fetch_table_name_list()
+            actual_tables = con.fetch_table_names()
 
-            print_test_result(expected=expected_table_list, actual=actual_table_list)
+            print_test_result(expected=expected_tables, actual=actual_tables)
 
-            assert set(actual_table_list) == set(expected_table_list)
+            assert set(actual_tables) == set(expected_tables)
 
             actual_data = con.select("*", table_name=table_name).fetchall()
             expected_data = [
@@ -412,17 +427,17 @@ class Test_sqlitebiter_file(object):
             assert expected_data == actual_data
 
             # third execution without --append option (overwrite) ---
-            result = runner.invoke(cmd, ["-o", db_path, "file"] + file_list)
+            result = runner.invoke(cmd, ["-o", db_path, "file"] + files)
             print_traceback(result)
             assert result.exit_code == ExitCode.SUCCESS
 
-            con = simplesqlite.SimpleSQLite(db_path, "r")
+            con = SimpleSQLite(db_path, "r")
 
-            actual_table_list = con.fetch_table_name_list()
+            actual_tables = con.fetch_table_names()
 
-            print_test_result(expected=expected_table_list, actual=actual_table_list)
+            print_test_result(expected=expected_tables, actual=actual_tables)
 
-            assert set(actual_table_list) == set(expected_table_list)
+            assert set(actual_tables) == set(expected_tables)
 
             actual_data = con.select("*", table_name=table_name).fetchall()
             expected_data = [(1, 4.0, "a"), (2, 2.1, "bb"), (3, 120.9, "ccc")]
@@ -436,19 +451,19 @@ class Test_sqlitebiter_file(object):
         runner = CliRunner()
 
         with runner.isolated_filesystem():
-            file_list = [valid_json_multi_file_2_1(), valid_json_multi_file_2_2()]
+            files = [valid_json_multi_file_2_1(), valid_json_multi_file_2_2()]
 
-            result = runner.invoke(cmd, ["-o", db_path, "file"] + file_list)
+            result = runner.invoke(cmd, ["-o", db_path, "file"] + files)
             print_traceback(result)
             assert result.exit_code == ExitCode.SUCCESS
 
-            con = simplesqlite.SimpleSQLite(db_path, "r")
-            expected_table_list = ["multij2", SourceInfo.get_table_name()]
-            actual_table_list = con.fetch_table_name_list()
+            con = SimpleSQLite(db_path, "r")
+            expected_tables = ["multij2", SourceInfo.get_table_name()]
+            actual_tables = con.fetch_table_names()
 
-            print_test_result(expected=expected_table_list, actual=actual_table_list)
+            print_test_result(expected=expected_tables, actual=actual_tables)
 
-            assert set(actual_table_list) == set(expected_table_list)
+            assert set(actual_tables) == set(expected_tables)
 
             expected_data_table = {
                 "multij2": [
@@ -461,7 +476,7 @@ class Test_sqlitebiter_file(object):
                 ]
             }
 
-            for table in con.fetch_table_name_list():
+            for table in con.fetch_table_names():
                 if table == SourceInfo.get_table_name():
                     continue
 
@@ -482,26 +497,26 @@ class Test_sqlitebiter_file(object):
         runner = CliRunner()
 
         with runner.isolated_filesystem():
-            file_list = [valid_json_multi_file_2_2(), valid_json_multi_file_2_3()]
+            files = [valid_json_multi_file_2_2(), valid_json_multi_file_2_3()]
 
-            result = runner.invoke(cmd, ["-o", db_path, "file"] + file_list)
+            result = runner.invoke(cmd, ["-o", db_path, "file"] + files)
             print_traceback(result)
             assert result.exit_code == ExitCode.SUCCESS
 
-            con = simplesqlite.SimpleSQLite(db_path, "r")
-            expected_table_list = ["multij2", "multij2_1", SourceInfo.get_table_name()]
-            actual_table_list = con.fetch_table_name_list()
+            con = SimpleSQLite(db_path, "r")
+            expected_tables = ["multij2", "multij2_1", SourceInfo.get_table_name()]
+            actual_tables = con.fetch_table_names()
 
-            print_test_result(expected=expected_table_list, actual=actual_table_list)
+            print_test_result(expected=expected_tables, actual=actual_tables)
 
-            assert set(actual_table_list) == set(expected_table_list)
+            assert set(actual_tables) == set(expected_tables)
 
             expected_data_table = {
                 "multij2": [(1, 4.0, "a"), (2, 2.1, "bb"), (3, 120.9, "ccc")],
                 "multij2_1": [(u"abc", u"a", 4.0), (u"abc", u"bb", 2.1), (u"abc", u"ccc", 120.9)],
             }
 
-            for table in con.fetch_table_name_list():
+            for table in con.fetch_table_names():
                 if table == SourceInfo.get_table_name():
                     continue
 
@@ -528,7 +543,7 @@ class Test_sqlitebiter_file(object):
 
             assert result.exit_code == ExitCode.SUCCESS
 
-            con = simplesqlite.SimpleSQLite(db_path, "r")
+            con = SimpleSQLite(db_path, "r")
             expected = set(
                 [
                     "ratings",
@@ -544,4 +559,100 @@ class Test_sqlitebiter_file(object):
                 ]
             )
 
-            assert set(con.fetch_table_name_list()) == expected
+            assert set(con.fetch_table_names()) == expected
+
+    def test_normal_not_exit_file(self):
+        runner = CliRunner()
+
+        with runner.isolated_filesystem():
+            result = runner.invoke(cmd, ["file", "not_exist.csv"])
+            print_traceback(result)
+
+            assert result.exit_code == ExitCode.NO_INPUT
+
+    def test_normal_type_hint_header(self):
+        runner = CliRunner()
+        basename = "type_hint_header"
+        file_path = "{}.csv".format(basename)
+        db_path = "{}.sqlite".format(basename)
+
+        with runner.isolated_filesystem():
+            with open(file_path, "w") as f:
+                f.write(
+                    dedent(
+                        """\
+                        "a text","b integer","c real"
+                        1,"1","1.1"
+                        2,"2","1.2"
+                        3,"3","1.3"
+                        """
+                    )
+                )
+                f.flush()
+
+            result = runner.invoke(cmd, ["--type-hint-header", "-o", db_path, "file", file_path])
+            print_traceback(result)
+            assert result.exit_code == ExitCode.SUCCESS
+
+            con = SimpleSQLite(db_path, "r")
+            tbldata = con.select_as_tabledata(basename)
+            assert tbldata.headers == ["a text", "b integer", "c real"]
+            assert tbldata.rows == [("1", 1, 1.1), ("2", 2, 1.2), ("3", 3, 1.3)]
+
+    def test_normal_add_primary_key(self):
+        runner = CliRunner()
+        basename = "add_primary_key"
+        file_path = "{}.csv".format(basename)
+        db_path = "{}.sqlite".format(basename)
+
+        with runner.isolated_filesystem():
+            with open(file_path, "w") as f:
+                f.write(
+                    dedent(
+                        """\
+                        "a","b"
+                        11,"xyz"
+                        22,"abc"
+                        """
+                    )
+                )
+                f.flush()
+
+            result = runner.invoke(
+                cmd, ["--add-primary-key", "id", "-o", db_path, "file", file_path]
+            )
+            print_traceback(result)
+            assert result.exit_code == ExitCode.SUCCESS
+
+            con = SimpleSQLite(db_path, "r")
+            tbldata = con.select_as_tabledata(basename)
+            assert tbldata.headers == ["id", "a", "b"]
+            assert tbldata.rows == [(1, 11, "xyz"), (2, 22, "abc")]
+
+    def test_normal_no_type_inference(self):
+        runner = CliRunner()
+        basename = "no_type_inference"
+        file_path = "{}.csv".format(basename)
+        db_path = "{}.sqlite".format(basename)
+
+        with runner.isolated_filesystem():
+            with open(file_path, "w") as f:
+                f.write(
+                    dedent(
+                        """\
+                        "a","b"
+                        11,"xyz"
+                        22,"abc"
+                        """
+                    )
+                )
+                f.flush()
+
+            result = runner.invoke(cmd, ["--no-type-inference", "-o", db_path, "file", file_path])
+            print_traceback(result)
+            assert result.exit_code == ExitCode.SUCCESS
+
+            con = SimpleSQLite(db_path, "r")
+            tbldata = con.select_as_tabledata(basename)
+            assert tbldata.headers == ["a", "b"]
+            assert tbldata.rows == [("11", "xyz"), ("22", "abc")]
