@@ -25,11 +25,7 @@ TEST_TABLE_NAME_B = "test_table_b"
 @pytest.fixture
 def con_a0():
     con = SimpleSQLite("tmp_a0.sqlite", "w")
-    con.create_table_from_data_matrix(
-        table_name=TEST_TABLE_NAME_A,
-        attr_name_list=["attr_a", "attr_b"],
-        data_matrix=[[1, 2], [3, 4]],
-    )
+    con.create_table_from_data_matrix(TEST_TABLE_NAME_A, ["attr_a", "attr_b"], [[1, 2], [3, 4]])
 
     return con
 
@@ -37,11 +33,7 @@ def con_a0():
 @pytest.fixture
 def con_a1():
     con = SimpleSQLite("tmp_a1.sqlite", "w")
-    con.create_table_from_data_matrix(
-        table_name=TEST_TABLE_NAME_A,
-        attr_name_list=["attr_a", "attr_b"],
-        data_matrix=[[11, 12], [13, 14]],
-    )
+    con.create_table_from_data_matrix(TEST_TABLE_NAME_A, ["attr_a", "attr_b"], [[11, 12], [13, 14]])
 
     return con
 
@@ -49,11 +41,7 @@ def con_a1():
 @pytest.fixture
 def con_b0():
     con = SimpleSQLite("tmp_b0.sqlite", "w")
-    con.create_table_from_data_matrix(
-        table_name=TEST_TABLE_NAME_B,
-        attr_name_list=["ba", "bb"],
-        data_matrix=[[101, 102], [103, 104]],
-    )
+    con.create_table_from_data_matrix(TEST_TABLE_NAME_B, ["ba", "bb"], [[101, 102], [103, 104]])
 
     return con
 
@@ -71,9 +59,7 @@ class Test_sqlitebiter_file_sqlite_merge(object):
             assert result.exit_code == ExitCode.SUCCESS
 
             expected = TableData(
-                table_name=TEST_TABLE_NAME_A,
-                header_list=["attr_a", "attr_b"],
-                row_list=[[1, 2], [3, 4], [11, 12], [13, 14]],
+                TEST_TABLE_NAME_A, ["attr_a", "attr_b"], [[1, 2], [3, 4], [11, 12], [13, 14]]
             )
             for tabledata in SqliteFileLoader(out_db_path).load():
                 if tabledata.table_name == SourceInfo.get_table_name():
@@ -93,16 +79,8 @@ class Test_sqlitebiter_file_sqlite_merge(object):
             assert result.exit_code == ExitCode.SUCCESS
 
             expected_list = [
-                TableData(
-                    table_name=TEST_TABLE_NAME_A,
-                    header_list=["attr_a", "attr_b"],
-                    row_list=[[1, 2], [3, 4]],
-                ),
-                TableData(
-                    table_name=TEST_TABLE_NAME_B,
-                    header_list=["ba", "bb"],
-                    row_list=[[101, 102], [103, 104]],
-                ),
+                TableData(TEST_TABLE_NAME_A, ["attr_a", "attr_b"], [[1, 2], [3, 4]]),
+                TableData(TEST_TABLE_NAME_B, ["ba", "bb"], [[101, 102], [103, 104]]),
             ]
             for tabledata in SqliteFileLoader(out_db_path).load():
                 if tabledata.table_name == SourceInfo.get_table_name():
